==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/script/InvocationInfo.hpp <==
#ifndef _COM_SUN_STAR_SCRIPT_INVOCATIONINFO_HPP_
#define _COM_SUN_STAR_SCRIPT_INVOCATIONINFO_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_INVOCATIONINFO_HDL_
#include "com/sun/star/script/InvocationInfo.hdl"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_MEMBERTYPE_HPP_
#include "com/sun/star/script/MemberType.hpp"
#endif
#ifndef _COM_SUN_STAR_REFLECTION_PARAMMODE_HPP_
#include "com/sun/star/reflection/ParamMode.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace script {

inline InvocationInfo::InvocationInfo() SAL_THROW( () )
    : aName()
    , eMemberType(::com::sun::star::script::MemberType_METHOD)
    , PropertyAttribute(0)
    , aType()
    , aParamTypes()
    , aParamModes()
{
}

inline InvocationInfo::InvocationInfo(const ::rtl::OUString& aName_, const ::com::sun::star::script::MemberType& eMemberType_, const ::sal_Int16& PropertyAttribute_, const ::com::sun::star::uno::Type& aType_, const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type >& aParamTypes_, const ::com::sun::star::uno::Sequence< ::com::sun::star::reflection::ParamMode >& aParamModes_) SAL_THROW( () )
    : aName(aName_)
    , eMemberType(eMemberType_)
    , PropertyAttribute(PropertyAttribute_)
    , aType(aType_)
    , aParamTypes(aParamTypes_)
    , aParamModes(aParamModes_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::script::InvocationInfo const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.script.InvocationInfo");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_SCRIPT_INVOCATIONINFO_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/script/InvocationInfo.hpp <==
#ifndef _COM_SUN_STAR_SCRIPT_INVOCATIONINFO_HPP_
#define _COM_SUN_STAR_SCRIPT_INVOCATIONINFO_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_INVOCATIONINFO_HDL_
#include "com/sun/star/script/InvocationInfo.hdl"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_MEMBERTYPE_HPP_
#include "com/sun/star/script/MemberType.hpp"
#endif
#ifndef _COM_SUN_STAR_REFLECTION_PARAMMODE_HPP_
#include "com/sun/star/reflection/ParamMode.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace script {

inline InvocationInfo::InvocationInfo() SAL_THROW( () )
    : aName()
    , eMemberType(::com::sun::star::script::MemberType_METHOD)
    , PropertyAttribute(0)
    , aType()
    , aParamTypes()
    , aParamModes()
{
}

inline InvocationInfo::InvocationInfo(const ::rtl::OUString& aName_, const ::com::sun::star::script::MemberType& eMemberType_, const ::sal_Int16& PropertyAttribute_, const ::com::sun::star::uno::Type& aType_, const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type >& aParamTypes_, const ::com::sun::star::uno::Sequence< ::com::sun::star::reflection::ParamMode >& aParamModes_) SAL_THROW( () )
    : aName(aName_)
    , eMemberType(eMemberType_)
    , PropertyAttribute(PropertyAttribute_)
    , aType(aType_)
    , aParamTypes(aParamTypes_)
    , aParamModes(aParamModes_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace script {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::script::InvocationInfo const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.script.InvocationInfo");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::script::InvocationInfo const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::script::InvocationInfo >::get();
}

#endif // _COM_SUN_STAR_SCRIPT_INVOCATIONINFO_HPP_
